@@ -23,88 +23,76 @@ from aliyunsdkdas.endpoint import endpoint_data
 class AddHDMInstanceRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'DAS', '2020-01-16', 'AddHDMInstance','das')
+		RpcRequest.__init__(self, 'DAS', '2020-01-16', 'AddHDMInstance')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_NetworkType(self):
+	def get_NetworkType(self): # String
 		return self.get_query_params().get('NetworkType')
 
-	def set_NetworkType(self,NetworkType):
-		self.add_query_param('NetworkType',NetworkType)
-
-	def get_Password(self):
+	def set_NetworkType(self, NetworkType):  # String
+		self.add_query_param('NetworkType', NetworkType)
+	def get_Password(self): # String
 		return self.get_query_params().get('Password')
 
-	def set_Password(self,Password):
-		self.add_query_param('Password',Password)
-
-	def get_Engine(self):
+	def set_Password(self, Password):  # String
+		self.add_query_param('Password', Password)
+	def get_Engine(self): # String
 		return self.get_query_params().get('Engine')
 
-	def set_Engine(self,Engine):
-		self.add_query_param('Engine',Engine)
-
-	def get___context(self):
+	def set_Engine(self, Engine):  # String
+		self.add_query_param('Engine', Engine)
+	def get___context(self): # String
 		return self.get_query_params().get('__context')
 
-	def set___context(self,__context):
-		self.add_query_param('__context',__context)
-
-	def get_Ip(self):
+	def set___context(self, __context):  # String
+		self.add_query_param('__context', __context)
+	def get_Ip(self): # String
 		return self.get_query_params().get('Ip')
 
-	def set_Ip(self,Ip):
-		self.add_query_param('Ip',Ip)
-
-	def get_InstanceAlias(self):
+	def set_Ip(self, Ip):  # String
+		self.add_query_param('Ip', Ip)
+	def get_InstanceAlias(self): # String
 		return self.get_query_params().get('InstanceAlias')
 
-	def set_InstanceAlias(self,InstanceAlias):
-		self.add_query_param('InstanceAlias',InstanceAlias)
-
-	def get_InstanceArea(self):
+	def set_InstanceAlias(self, InstanceAlias):  # String
+		self.add_query_param('InstanceAlias', InstanceAlias)
+	def get_InstanceArea(self): # String
 		return self.get_query_params().get('InstanceArea')
 
-	def set_InstanceArea(self,InstanceArea):
-		self.add_query_param('InstanceArea',InstanceArea)
-
-	def get_InstanceId(self):
+	def set_InstanceArea(self, InstanceArea):  # String
+		self.add_query_param('InstanceArea', InstanceArea)
+	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
-	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
-
-	def get_Port(self):
+	def set_InstanceId(self, InstanceId):  # String
+		self.add_query_param('InstanceId', InstanceId)
+	def get_Port(self): # String
 		return self.get_query_params().get('Port')
 
-	def set_Port(self,Port):
-		self.add_query_param('Port',Port)
-
-	def get_FlushAccount(self):
+	def set_Port(self, Port):  # String
+		self.add_query_param('Port', Port)
+	def get_FlushAccount(self): # String
 		return self.get_query_params().get('FlushAccount')
 
-	def set_FlushAccount(self,FlushAccount):
-		self.add_query_param('FlushAccount',FlushAccount)
-
-	def get_VpcId(self):
+	def set_FlushAccount(self, FlushAccount):  # String
+		self.add_query_param('FlushAccount', FlushAccount)
+	def get_VpcId(self): # String
 		return self.get_query_params().get('VpcId')
 
-	def set_VpcId(self,VpcId):
-		self.add_query_param('VpcId',VpcId)
-
-	def get_Region(self):
+	def set_VpcId(self, VpcId):  # String
+		self.add_query_param('VpcId', VpcId)
+	def get_Region(self): # String
 		return self.get_query_params().get('Region')
 
-	def set_Region(self,Region):
-		self.add_query_param('Region',Region)
-
-	def get_Username(self):
+	def set_Region(self, Region):  # String
+		self.add_query_param('Region', Region)
+	def get_Username(self): # String
 		return self.get_query_params().get('Username')
 
-	def set_Username(self,Username):
-		self.add_query_param('Username',Username)
\ No newline at end of file
+	def set_Username(self, Username):  # String
+		self.add_query_param('Username', Username)
