@@ -101,3 +101,13 @@ class GetQueryOptimizeDataStatsRequest(RpcRequest):
 
 	def set_Time(self, Time):  # String
 		self.add_query_param('Time', Time)
+	def get_Region(self): # String
+		return self.get_query_params().get('Region')
+
+	def set_Region(self, Region):  # String
+		self.add_query_param('Region', Region)
+	def get_User(self): # String
+		return self.get_query_params().get('User')
+
+	def set_User(self, User):  # String
+		self.add_query_param('User', User)
