@@ -56,3 +56,8 @@ class GetQueryOptimizeDataTrendRequest(RpcRequest):
 
 	def set_End(self, End):  # String
 		self.add_query_param('End', End)
+	def get_Region(self): # String
+		return self.get_query_params().get('Region')
+
+	def set_Region(self, Region):  # String
+		self.add_query_param('Region', Region)
