@@ -46,3 +46,8 @@ class GetQueryOptimizeRuleListRequest(RpcRequest):
 
 	def set_InstanceIds(self, InstanceIds):  # String
 		self.add_query_param('InstanceIds', InstanceIds)
+	def get_Region(self): # String
+		return self.get_query_params().get('Region')
+
+	def set_Region(self, Region):  # String
+		self.add_query_param('Region', Region)
