@@ -31,30 +31,30 @@ class GetRequestDiagnosisPageRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_EndTime(self): # String
+	def get_EndTime(self): # Long
 		return self.get_query_params().get('EndTime')
 
-	def set_EndTime(self, EndTime):  # String
+	def set_EndTime(self, EndTime):  # Long
 		self.add_query_param('EndTime', EndTime)
-	def get_StartTime(self): # String
+	def get_StartTime(self): # Long
 		return self.get_query_params().get('StartTime')
 
-	def set_StartTime(self, StartTime):  # String
+	def set_StartTime(self, StartTime):  # Long
 		self.add_query_param('StartTime', StartTime)
 	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
 	def set_InstanceId(self, InstanceId):  # String
 		self.add_query_param('InstanceId', InstanceId)
-	def get_PageNo(self): # String
+	def get_PageNo(self): # Integer
 		return self.get_query_params().get('PageNo')
 
-	def set_PageNo(self, PageNo):  # String
+	def set_PageNo(self, PageNo):  # Integer
 		self.add_query_param('PageNo', PageNo)
-	def get_PageSize(self): # String
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self, PageSize):  # String
+	def set_PageSize(self, PageSize):  # Integer
 		self.add_query_param('PageSize', PageSize)
 	def get_NodeId(self): # String
 		return self.get_query_params().get('NodeId')
