@@ -31,11 +31,21 @@ class GetRequestDiagnosisResultRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_SqlId(self): # String
+		return self.get_query_params().get('SqlId')
+
+	def set_SqlId(self, SqlId):  # String
+		self.add_query_param('SqlId', SqlId)
 	def get_MessageId(self): # String
 		return self.get_query_params().get('MessageId')
 
 	def set_MessageId(self, MessageId):  # String
 		self.add_query_param('MessageId', MessageId)
+	def get_Source(self): # String
+		return self.get_query_params().get('Source')
+
+	def set_Source(self, Source):  # String
+		self.add_query_param('Source', Source)
 	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
