@@ -23,16 +23,16 @@ from aliyunsdkdas.endpoint import endpoint_data
 class StopCloudBenchTaskRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'DAS', '2020-01-16', 'StopCloudBenchTask','das')
+		RpcRequest.__init__(self, 'DAS', '2020-01-16', 'StopCloudBenchTask')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_TaskId(self):
+	def get_TaskId(self): # String
 		return self.get_query_params().get('TaskId')
 
-	def set_TaskId(self,TaskId):
-		self.add_query_param('TaskId',TaskId)
\ No newline at end of file
+	def set_TaskId(self, TaskId):  # String
+		self.add_query_param('TaskId', TaskId)
